==> kubernetes-model-1.0.27-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointPortBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class EndpointPortBuilder extends EndpointPortFluent<EndpointPortBuilder> implements VisitableBuilder<EndpointPort,EndpointPortBuilder>{

     EndpointPortFluent<?> fluent;
public EndpointPortBuilder(){
    this(new EndpointPort());
}
public EndpointPortBuilder( EndpointPortFluent<?> fluent ){
    this(fluent, new EndpointPort());
}
public EndpointPortBuilder( EndpointPortFluent<?> fluent , EndpointPort instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withPort(instance.getPort()); fluent.withProtocol(instance.getProtocol()); 
}
public EndpointPortBuilder( EndpointPort instance ){
    this.fluent = this; this.withName(instance.getName()); this.withPort(instance.getPort()); this.withProtocol(instance.getProtocol()); 
}

public EditableEndpointPort build(){
    EditableEndpointPort buildable = new EditableEndpointPort(fluent.getName(),fluent.getPort(),fluent.getProtocol());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
EndpointPortBuilder that = (EndpointPortBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.36-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointPortBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class EndpointPortBuilder extends EndpointPortFluentImpl<EndpointPortBuilder> implements VisitableBuilder<EndpointPort,EndpointPortBuilder>{

     EndpointPortFluent<?> fluent;
public EndpointPortBuilder(){
    this(new EndpointPort());
}
public EndpointPortBuilder( EndpointPortFluent<?> fluent ){
    this(fluent, new EndpointPort());
}
public EndpointPortBuilder( EndpointPortFluent<?> fluent , EndpointPort instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withPort(instance.getPort()); fluent.withProtocol(instance.getProtocol()); 
}
public EndpointPortBuilder( EndpointPort instance ){
    this.fluent = this; this.withName(instance.getName()); this.withPort(instance.getPort()); this.withProtocol(instance.getProtocol()); 
}

public EditableEndpointPort build(){
    EditableEndpointPort buildable = new EditableEndpointPort(fluent.getName(),fluent.getPort(),fluent.getProtocol());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
EndpointPortBuilder that = (EndpointPortBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
